{ config, pkgs, ... }:

{
  imports =
    [
      ../../base.nix
      ../../common/metrics-exporters.nix
      ./hardware-configuration.nix

      # Infrastructure
      ./backup.nix
      ./libvirt.nix
      ./services/nginx.nix
      ./services/pihole.nix
      ./services/postgresql.nix
      ./services/wireguard.nix

      # Services
      ./services/flame.nix
      ./services/gitea.nix
      ./services/hedgedoc.nix
      ./services/home-assistant.nix
      ./services/matrix
      ./services/monitoring
      ./services/microbin.nix
      ./services/minecraft.nix
      ./services/vaultwarden.nix
  ];

  networking = {
    hostName = "defiant";
    defaultGateway = "192.168.10.1";
    interfaces.enp3s0.ipv4 = {
      addresses = [
        { address = "192.168.10.175"; prefixLength = 24; } # Main IP for defiant, internal
      ];
    };
    hostId = "8e84f235";
  };

  sops.defaultSopsFile = ../../secrets/defiant/defiant.yaml;

  environment.variables = { EDITOR = "vim"; };
  environment.systemPackages = with pkgs; [
    zfs
  ];

  boot = {
    zfs.extraPools = [ "tank" ];
    supportedFilesystems = [ "zfs" ];
    kernelPackages = config.boot.zfs.package.latestCompatibleLinuxPackages;
  };
  services.prometheus.exporters.zfs.enable = true;

  virtualisation.docker.enable = true;
  virtualisation.oci-containers.backend = "docker";

  system.stateVersion = "23.11";
}

