{ config, pkgs, lib, ... }:

{
  imports =
    [
      ../../base.nix
      ../../common/metrics-exporters.nix
      ./hardware-configuration.nix
      ./desktop.nix
  ];

  virtualisation.docker.enable = true;

  networking = {
    hostName = "edison";
    defaultGateway = "192.168.10.1";

    interfaces.enp4s0.useDHCP = false;
    interfaces.enp4s0.ipv4.addresses = [
      { address = "192.168.10.170"; prefixLength = 24; }
    ];

    hostId = "8e84b281";
  };

  console.keyMap = "us";

  # sops.defaultSopsFile = ../../secrets/edison/edison.yaml;

  environment.variables = { EDITOR = "vim"; };
  environment.systemPackages = with pkgs; [
    pavucontrol
    gparted
    unstable.hydrus
  ];

  programs.steam.enable = true;

  nixpkgs.config.allowUnfreePredicate = pkg: builtins.elem (lib.getName pkg) [
    "nvidia-x11"
    "nvidia-settings"
    "steam"
    "steam-original"
    "steam-run"
  ];

  system.stateVersion = "23.05";
}

